@@ -4,11 +4,9 @@
 srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
-PKG_NAME="cheese"
-
 (test -f $srcdir/src/cheese-main.vala) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
-    echo " top-level $PKG_NAME directory"
+    echo " top-level Cheese directory"
     exit 1
 }
 
@@ -17,4 +15,4 @@ which gnome-autogen.sh || {
     exit 1
 }
 
-ACLOCAL_FLAGS="$ACLOCAL_FLAGS" USE_GNOME2_MACROS=1 . gnome-autogen.sh
+. gnome-autogen.sh
